% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/h2o.r
\name{h2osteam.launch_h2o_cluster}
\alias{h2osteam.launch_h2o_cluster}
\title{Launch a new H2O cluster on Hadoop.}
\usage{
h2osteam.launch_h2o_cluster(
  conn,
  name = NA_character_,
  version = NA_character_,
  profile_name = NA_character_,
  nodes = NA_integer_,
  node_cpus = NA_integer_,
  yarn_vcores = NA_integer_,
  node_memory_gb = NA_integer_,
  extra_memory_percent = NA_integer_,
  max_idle_h = NA_integer_,
  max_uptime_h = NA_integer_,
  timeout_s = NA_integer_,
  yarn_queue = "",
  leader_node_id = 0
)
}
\arguments{
\item{conn}{The \code{SteamConnection} object obtained by \code{h2osteam.login}.}

\item{name}{Name of the cluster.}

\item{version}{Version of H2O that will be used in the cluster.}

\item{profile_name}{(Optional) Specify name of an existing profile that will be used for this cluster.}

\item{nodes}{(Optional) Number of nodes of the H2O cluster.}

\item{node_cpus}{(Optional) Number of CPUs/threads used by H2O on a single node. Specify '0' to use all available CPUs/threads.}

\item{yarn_vcores}{(Optional) Number of YARN virtual cores per cluster node. Should match node_cpus.}

\item{node_memory_gb}{(Optional) Amount of memory in GB allocated for a single H2O node.}

\item{extra_memory_percent}{(Optional) Percentage of extra memory that will be allocated outside of H2O JVM for algos like XGBoost.}

\item{max_idle_h}{(Optional) Maximum amount of time in hours the cluster can be idle before shutting down.}

\item{max_uptime_h}{(Optional) Maximum amount of time in hours the cluster will be up before shutting down.}

\item{timeout_s}{(Optional) Maximum amount of time in seconds to wait for the H2O cluster to start.}

\item{yarn_queue}{(Optional) Name of the YARN queue where the cluster will be placed.}

\item{leader_node_id}{(Optional) ID of the H2O leader node.}
}
\value{
H2O cluster connection configuration that can be passed to \code{h2o.connect(config = config)}.
}
\description{
Launches a new H2O cluster on Hadoop using the parameters described below.
You do not need to specify all parameters. In that case they will be filled
based on the default value of the selected profile.
The process of launching a cluster can take up to 5 minutes.
}
\examples{
\dontrun{
conn <- h2osteam.login(url = "https://steam.h2o.ai:9555",
                       username = "user01", password = "token-here")
config <- h2osteam.launch_h2o_cluster(conn, name = "test-cluster", version = "3.30.0.1",
                                      nodes = 5, node_memory_gb = 20)
h2o.connect(config = config)
}

}
