% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/h2ok8s.r
\name{h2osteam.launch_h2o_kubernetes_cluster}
\alias{h2osteam.launch_h2o_kubernetes_cluster}
\title{Launch a new H2O cluster on Kubernetes.}
\usage{
h2osteam.launch_h2o_kubernetes_cluster(
  conn,
  name = NA_character_,
  profile_name = NA_character_,
  version = NA_character_,
  dataset_size_gb = 0,
  dataset_dimension = c(0, 0),
  nodes = NA_integer_,
  node_cpus = NA_integer_,
  node_gpus = NA_integer_,
  node_memory_gb = NA_integer_,
  max_idle_h = NA_integer_,
  max_uptime_h = NA_integer_,
  timeout_s = NA_integer_,
  volumes = NA_character_
)
}
\arguments{
\item{conn}{The \code{SteamConnection} object obtained by \code{h2osteam.login}.}

\item{name}{Name of the cluster.}

\item{profile_name}{(Optional) Specify name of an existing profile that will be used for this cluster.}

\item{version}{Version of H2O that will be used in the cluster.}

\item{dataset_size_gb}{(Optional) Specify size of your uncompressed dataset. For compressed data source, use dataset_dimension parameter. Cluster parameters will be preset to accommodate your dataset within selected profile limits. Does not override user-specified values.}

\item{dataset_dimension}{(Optional) Array of (n_rows, n_cols) representing an estimation of dataset dimensions. Use this parameter when you intend to use compressed data source like Parquet format. Cluster parameters will be preset to accommodate your dataset within selected profile limits. Does not override user-specified values.}

\item{nodes}{(Optional) Number of nodes of the H2O cluster.}

\item{node_cpus}{(Optional) Number of CPUs/threads used by H2O on a single node. Specify '0' to use all available CPUs/threads.}

\item{node_gpus}{(Optional) Number of GPUs per node}

\item{node_memory_gb}{(Optional) Amount of memory in GB allocated for a single H2O node.}

\item{max_idle_h}{(Optional) Maximum amount of time in hours the cluster can be idle before shutting down.}

\item{max_uptime_h}{(Optional) Maximum amount of time in hours the cluster will be up before shutting down.}

\item{timeout_s}{(Optional) Maximum amount of time in seconds to wait for the H2O cluster to start.}

\item{volumes}{(Optional) Specify unbound volumes to mount with this instance.}
}
\value{
H2O cluster connection configuration that can be passed to \code{h2o.connect(config = config)}.
}
\description{
Launches a new H2O cluster on Kubernetes using the parameters described below.
You do not need to specify all parameters. In that case they will be filled
based on the default value of the selected profile.
The process of launching a cluster can take up to 5 minutes.
}
\examples{
\dontrun{
conn <- h2osteam.login(url = "https://steam.h2o.ai:9555",
                       username = "user01", password = "token-here")
config <- h2osteam.launch_h2o_kubernetes_cluster(conn, name = "test-cluster", version = "3.30.0.1",
                                      nodes = 5, node_memory_gb = 20)
h2o.connect(config = config)
}

}
